@@ -11,7 +11,7 @@ from math import ceil
 from f61d.setu import *
 
 
-VERSION = (0,5,16)
+VERSION = (0,5,17)
 VERSION = '.'.join(map(str, VERSION))
 
 invert = lambda a,n:pow(a,-1,n)
@@ -36,7 +36,7 @@ help_cont[12] = 'crt     : Chinese Remainder Theory'
 help_cont[13] = 'mtank   : 幻影坦克 Mirage tank maker'
 help_cont[14] = 'setu    : get a setu with your xp'
 help_cont[15] = 'fast_setu: get a random setu'
-
+help_cont[16] = 'parse_header: parse a header from Chrome'
 
 
 def formatNumber(x):
@@ -266,3 +266,9 @@ def mtank(outerPic,innerPic,output='tank.png'):
     p2 = p2.convert('L')
     make(p1,p2,getDesktop() + '\\' + output)
 
+
+def parse_header(s):
+    hds = s
+    hds = hds.split('\n')
+    hds = {i.split(': ',1)[0].replace(':',''):i.split(': ',1)[1] for i in hds}
+    return hds
